
import React, { useState } from 'react';
import { ChevronDown, ChevronUp } from 'lucide-react';
import { Collapsible, CollapsibleContent, CollapsibleTrigger } from "@/components/ui/collapsible";

const FAQSection = () => {
  const [openItems, setOpenItems] = useState<Record<number, boolean>>({});
  
  const faqs = [
    {
      question: "What does the travel guide include?",
      answer: "Your purchase includes lifetime access to the digital version of the guide, delivered in PDF format."
    },
    {
      question: "How many cities are covered in the guide?",
      answer: "There are currently 17 of my favorite digital nomad cities around the world."
    },
    {
      question: "How do the lifetime updates work?",
      answer: "If you buy the Pro Guide, you'll receive lifetime updates via email every time I explore a new city. Upcoming destinations, in no particular order, include Buenos Aires, Barcelona, Istanbul, Sri Lanka, Cape Town, and Sydney."
    },
    {
      question: "What if I'm having trouble opening the guide?",
      answer: "The guide automatically downloads when you click the link in your email. On mobile, it should open or appear in your downloads folder. On desktop, it will save to your files. If you run into any issues, email me at gabriel.meneses@tdcdigitalagency.com and I'll respond within 24 hours."
    },
    {
      question: "Is this guide only for designers?",
      answer: "While it's designed with digital designers in mind, anyone earning remotely and looking to live in nomad-friendly cities will benefit. That said, the systems, tips, and locations are especially helpful for creative professionals working remotely."
    },
    {
      question: "How is this different from free travel blogs or YouTube videos?",
      answer: "This guide is built on real-life experience, not SEO content created for clicks or viewer retention. Every city has been personally explored by me to save you hours of research and help you avoid tourist traps and unnecessary distractions."
    },
    {
      question: "Can I use this guide offline while traveling?",
      answer: "Yes. Once you download the PDF, you can access it anytime, even without Wi-Fi. It's travel-ready and works on mobile, tablet, or laptop."
    },
    {
      question: "Do I get updates automatically if I buy now?",
      answer: "Yes. If you purchase the Pro Guide, you'll automatically receive all future updates delivered to your inbox with no need to repurchase."
    },
    {
      question: "Is there a refund policy?",
      answer: "Absolutely. If the guide doesn't meet your expectations, just email gabriel.meneses@tdcdigitalagency.com within 30 days of purchase and I'll issue a full refund, no questions asked."
    },
    {
      question: "How do I get in touch with customer support?",
      answer: "Email gabriel.meneses@tdcdigitalagency.com and I'll get back to you within 24 business hours."
    }
  ];

  const toggleFAQ = (index: number) => {
    setOpenItems(current => ({
      ...current,
      [index]: !current[index]
    }));
  };
  
  return (
    <section id="faq" className="py-16 md:py-20 bg-nomad-sand/50">
      <div className="container px-4 md:px-0 mx-auto">
        <div className="md:max-w-[60%] mx-auto">
          <h2 className="text-3xl md:text-4xl font-bold text-left md:text-center mb-8">
            What Most Designers Ask Before Buying
          </h2>
          
          <div className="space-y-4">
            {faqs.map((faq, index) => (
              <Collapsible
                key={index}
                open={openItems[index] || false}
                onOpenChange={() => toggleFAQ(index)}
                className="border border-gray-200 rounded-lg overflow-hidden"
              >
                <CollapsibleTrigger className="w-full flex justify-between items-center p-5 text-left bg-nomad-sand/50 hover:bg-nomad-sand transition-colors">
                  <h3 className="text-lg font-medium">{faq.question}</h3>
                  {openItems[index] ? (
                    <ChevronUp className="w-5 h-5 text-nomad-terracotta" />
                  ) : (
                    <ChevronDown className="w-5 h-5 text-nomad-slate" />
                  )}
                </CollapsibleTrigger>
                <CollapsibleContent className="p-5 bg-white">
                  <p className="text-nomad-slate/80">{faq.answer}</p>
                </CollapsibleContent>
              </Collapsible>
            ))}
          </div>
        </div>
      </div>
    </section>
  );
};

export default FAQSection;
